Struct MsgRejectEvent
pub struct MsgRejectEvent<'a> { /* private fields */ }Expand description
Application-level message reject event
Received when a message is rejected at the application layer. This contains the message that was rejected.
Lifetime
The lifetime 'a ensures this event cannot outlive the callback scope.
Implementations
impl<'a> MsgRejectEvent<'a>
impl<'a> MsgRejectEvent<'a>
pub fn rejected_message(&self) -> Option<&'a FixMessage>
pub fn rejected_message(&self) -> Option<&'a FixMessage>
Get the rejected message
Returns the message that was rejected.
Returns
Some(&FixMessage)- The rejected messageNone- Should never happen (reject events always have a message)