Struct LogoutEvent
pub struct LogoutEvent<'a> { /* private fields */ }Expand description
Logout event - received when the session is closed
This event is only valid within the callback scope. It contains:
- Logout message (if session was closed by remote side)
- Reconnect flag (mutable) - set to true to trigger reconnection
Lifetime
The lifetime 'a ensures this event cannot outlive the callback scope.
Implementations
impl<'a> LogoutEvent<'a>
impl<'a> LogoutEvent<'a>
pub fn logout_message(&self) -> Option<&'a FixMessage>
pub fn logout_message(&self) -> Option<&'a FixMessage>
Get the incoming logout message
Returns the Logout message if the session was closed by the remote side.
Returns
Some(&FixMessage)- The logout message from the counterpartyNone- If the session was closed locally (no incoming message)
pub fn reconnect_flag(&self) -> bool
pub fn reconnect_flag(&self) -> bool
Get the reconnect flag
Defaults to false.
pub fn set_reconnect_flag(&mut self, reconnect: bool)
pub fn set_reconnect_flag(&mut self, reconnect: bool)